@@ -55,7 +55,7 @@ QOrientationReading::Orientation OrientationSensor::value() const
 
 bool OrientationSensor::available() const
 {
-    return  m_sensor->connectToBackend();
+    return m_sensor->connectToBackend();
 }
 
 bool OrientationSensor::enabled() const
@@ -71,12 +71,10 @@ void OrientationSensor::setEnabled(bool enable)
     m_enabled = enable;
 
     if (enable) {
-        connect(m_sensor, &QOrientationSensor::readingChanged,
-                this, &OrientationSensor::updateState);
+        connect(m_sensor, &QOrientationSensor::readingChanged, this, &OrientationSensor::updateState);
         m_sensor->start();
     } else {
-        disconnect(m_sensor, &QOrientationSensor::readingChanged,
-                   this, &OrientationSensor::updateState);
+        disconnect(m_sensor, &QOrientationSensor::readingChanged, this, &OrientationSensor::updateState);
         m_value = QOrientationReading::Undefined;
     }
     Q_EMIT enabledChanged(enable);
